@@ -50,4 +50,14 @@ test_that("ensure(s)_that works", {
     "Not square"
   )
 
+  expect_identical(1:10, ensure(1:10, is.integer))
+  expect_identical(1:10, ensure(1:10, is.integer, is.numeric))
+
+  expect_identical(check_that(1:10, is.vector(., "numeric")),  TRUE)
+  expect_identical(check_that(1:10, is.vector(., "character")), FALSE)
+
+  type_square <- ensures_that(identical(NCOL(.), NROW(.)))
+  expect_identical(check_that(iris, is.data.frame), TRUE)
+  expect_identical(check_that(iris, is.data.frame, +type_square), FALSE)
+
 })
